Actions, Resources, and Condition Keys for Amazon CloudFront - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon CloudFront.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon CloudFront

Amazon CloudFront (service prefix: `cloudfront`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon CloudFront
- Resources Defined by Amazon CloudFront
- Condition Keys for Amazon CloudFront

## Actions Defined by Amazon CloudFront

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateCloudFrontOriginAccessIdentity | This action creates a new CloudFront origin access identity (POST /2016-11-25/origin-access-identity/cloudfront). | Write |  |  |
CreateDistribution | This action creates a new web distribution (POST /2016-11-25/distribution). | Write |  |  |
CreateDistributionWithTags | This action creates a new web distribution with tags (POST /2016-11-25/distribution?WithTags). | Tagging |  |  |
CreateInvalidation | This action creates a new invalidation batch request (POST /2016-11-25/distribution/<DISTRIBUTION_ID>/invalidation). | Write |  |  |
CreateStreamingDistribution | This action creates a new RTMP distribution (POST /2016-11-25/streaming-distribution). | Write |  |  |
CreateStreamingDistributionWithTags | This action creates a new RTMP distribution with tags (POST /2016-11-25/streaming-distribution?WithTags). | Tagging |  |  |
DeleteCloudFrontOriginAccessIdentity | This action deletes a CloudFront origin access identity (DELETE /2016-11-25/origin-access-identity/cloudfront/<OAI_ID>). | Write |  |  |
DeleteDistribution | This action deletes a web distribution (DELETE /2016-11-25/distribution/<DISTRIBUTION_ID>). | Write |  |  |
DeleteStreamingDistribution | This action deletes an RTMP distribution (DELETE /2016-11-25/streaming-distribution/<DISTRIBUTION_ID>). | Write |  |  |
GetCloudFrontOriginAccessIdentity | Get the information about a CloudFront origin access identity (GET /2016-11-25/origin-access-identity/cloudfront/<OAI_ID>). | Read |  |  |
GetCloudFrontOriginAccessIdentityConfig | Get the configuration information about a Cloudfront origin access identity (GET /2016-11-25/origin-access-identity/cloudfront/<OAI_ID>/config). | Read |  |  |
GetDistribution | Get the information about a web distribution (GET /2016-11-25/distribution/<DISTRIBUTION_ID>). | Read |  |  |
GetDistributionConfig | Get the configuration information about a distribution (GET /2016-11-25/distribution/<DISTRIBUTION_ID>/config). | Read |  |  |
GetInvalidation | Get the information about an invalidation (GET /2016-11-25/distribution/<DISTRIBUTION_ID>/invalidation/<INVALIDATION_ID>). | Read |  |  |
GetStreamingDistribution | Get the information about an RTMP distribution (GET /2016-11-25/streaming-distribution/<DISTRIBUTION_ID>). | Read |  |  |
GetStreamingDistributionConfig | Get the configuration information about a streaming distribution (GET /2016-11-25/streaming-distribution/<DISTRIBUTION_ID>/config). | Read |  |  |
ListCloudFrontOriginAccessIdentities | List your CloudFront origin access identities (GET /2016-11-25/origin-access-identity/cloudfront?Marker=<MARKER>&MaxItems=<MAX_ITEMS>). | List |  |  |
ListDistributions | List the distributions associated with your AWS account (GET /2016-11-25/distribution?Marker=<MARKER>&MaxItems=<MAX_ITEMS>). | List |  |  |
ListDistributionsByWebACLId | List the distributions associated with your AWS account with given AWS WAF web ACL (GET /2016-11-25/distributionsByWebACLId/<WEB_ACL_ID>?Marker=<MARKER>&MaxItems=<MAX_ITEMS>). | List |  |  |
ListInvalidations | List your invalidation batches (GET /2016-11-25/distribution/<DISTRIBUTION_ID>/invalidation?Marker=<MARKER>&MaxItems=<MAX_ITEMS>). | List |  |  |
ListStreamingDistributions | List your RTMP distributions (GET /2016-11-25/streaming-distribution?Marker=<MARKER>&MaxItems=<MAX_ITEMS>). | List |  |  |
ListTagsForResource | List tags for a CloudFront resource (GET /2016-11-25/tagging?Resource=<RESOURCE>). | Read |  |  |
TagResource | Add tags to a CloudFront resource (POST /2016-11-25/tagging?Operation=Tag?Resource=<RESOURCE>). | Tagging |  |  |
UntagResource | Remove tags from a CloudFront resource (POST /2016-11-25/tagging?Operation=Untag?Resource=<RESOURCE>). | Tagging |  |  |
UpdateCloudFrontOriginAccessIdentity | This action sets the configuration for a CloudFront origin access identity (PUT /2016-11-25/origin-access-identity/cloudfront/<OAI_ID>/config). | Write |  |  |
UpdateDistribution | This action updates the configuration for a web distribution (PUT /2016-11-25/distribution/<DISTRIBUTION_ID>/config). | Write |  |  |
UpdateStreamingDistribution | This action updates the configuration for an RTMP distribution (PUT /2016-11-25/streaming-distribution/<DISTRIBUTION_ID>/config). | Write |  |  |

## Resources Defined by Amazon CloudFront

Amazon CloudFront does not support specifying a resource ARN in the `Resource` element of an IAM policy statement. To allow access to Amazon CloudFront, specify `“Resource”: “*”` in your policy.

## Condition Keys for Amazon CloudFront

CloudFront has no service-specific context keys that can be used in the `Condition` element of policy statements. For the list of the global context keys that are available to all services, see Available Keys for Conditions in the IAM Policy Reference.

On this page:

- Actions Defined by Amazon CloudFront
- Resources Defined by Amazon CloudFront
- Condition Keys for Amazon CloudFront

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more